@@ -163,13 +163,13 @@ void VocabularyView::slotCurrentChanged(const QModelIndex &current, const QModel
     if (current.isValid()) {
         entry = model()->data(current, VocabularyModel::EntryRole).value<KEduVocExpression *>();
     }
-    emit translationChanged(entry, VocabularyModel::translation(current.column()));
+    Q_EMIT translationChanged(entry, VocabularyModel::translation(current.column()));
 }
 
 void VocabularyView::reset()
 {
     QTableView::reset();
-    emit translationChanged(0, 0);
+    Q_EMIT translationChanged(0, 0);
 
     QList<int> visibleColumns;
     if (m_doc) {
@@ -256,7 +256,7 @@ void VocabularyView::deleteSelectedEntries(bool askConfirmation)
     }
 
     if (del) {
-        emit translationChanged(0, 0);
+        Q_EMIT translationChanged(0, 0);
         while (!selectionModel()->selectedIndexes().isEmpty()) {
             m_model->removeRows(selectionModel()->selectedIndexes()[0].row(), 1, QModelIndex());
         }
